==> firebase_ui_localizations-1.10.2.tar.gz: lib/src/lang/ja.dart <==
// Copyright 2023, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import '../default_localizations.dart';

class JaLocalizations extends FirebaseUILocalizationLabels {
  const JaLocalizations();

  @override
  String get accessDisabledErrorText => "このアカウントへのアクセスが一時的に無効になっています";

  @override
  String get arrayLabel => "配列";

  @override
  String get booleanLabel => "ブール値";

  @override
  String get cancelLabel => "キャンセル";

  @override
  String get chooseACountry => "国を選択";

  @override
  String get confirmPasswordDoesNotMatchErrorText => "パスワードが一致しません";

  @override
  String get confirmPasswordInputLabel => "パスワードを確認";

  @override
  String get confirmPasswordIsRequiredErrorText => "パスワードを確認してください";

  @override
  String get continueText => "続行";

  @override
  String get countryCode => "コード";

  @override
  String get credentialAlreadyInUseErrorText =>
      "このプロバイダは、すでに別のユーザー アカウントに関連付けられています。";

  @override
  String get deleteAccount => "アカウントを削除";

  @override
  String get differentMethodsSignInTitleText => "次のいずれかの方法を使用してログインします";

  @override
  String get disable => "無効にする";

  @override
  String get eastInitialLabel => "E";

  @override
  String get emailInputLabel => "メール";

  @override
  String get emailIsRequiredErrorText => "メールアドレスは必須です";

  @override
  String get emailLinkSignInButtonLabel => "マジックリンクでログイン";

  @override
  String get emailTakenErrorText => "このようなメールアドレスを持つアカウントはすでに存在します";

  @override
  String get enable => "有効にする";

  @override
  String get enableMoreSignInMethods => "その他のログイン方法を有効にします";

  @override
  String get enterSMSCodeText => "SMS コードを入力";

  @override
  String get findProviderForEmailTitleText => "メールアドレスを入力して続行";

  @override
  String get forgotPasswordButtonLabel => "パスワードをお忘れの場合";

  @override
  String get forgotPasswordHintText =>
      "メールアドレスを入力してください。パスワードを再設定するためのリンクが送信されます";

  @override
  String get forgotPasswordViewTitle => "パスワードをお忘れの場合";

  @override
  String get geopointLabel => "地理位置情報";

  @override
  String get goBackButtonLabel => "戻る";

  @override
  String get invalidCountryCode => "コードが無効です";

  @override
  String get isNotAValidEmailErrorText => "有効なメールアドレスを入力してください";

  @override
  String get latitudeLabel => "緯度";

  @override
  String get linkEmailButtonText => "次へ";

  @override
  String get longitudeLabel => "経度";

  @override
  String get mapLabel => "地図";

  @override
  String get mfaTitle => "2 段階認証プロセス";

  @override
  String get name => "名前";

  @override
  String get northInitialLabel => "N";

  @override
  String get nullLabel => "null";

  @override
  String get numberLabel => "番号";

  @override
  String get off => "オフ";

  @override
  String get on => "オン";

  @override
  String get passwordInputLabel => "パスワード";

  @override
  String get passwordIsRequiredErrorText => "パスワードは必須です";

  @override
  String get passwordResetEmailSentText =>
      "パスワードを再設定するためのリンクをメールでお送りしました。メールをご確認ください。";

  @override
  String get phoneInputLabel => "電話番号";

  @override
  String get phoneNumberInvalidErrorText => "電話番号が無効です";

  @override
  String get phoneNumberIsRequiredErrorText => "電話番号は必須です";

  @override
  String get phoneVerificationViewTitleText => "電話番号を入力してください";

  @override
  String get profile => "プロファイル";

  @override
  String get provideEmail => "メールアドレスとパスワードの入力";

  @override
  String get referenceLabel => "リファレンス";

  @override
  String get registerActionText => "登録";

  @override
  String get registerHintText => "アカウントをお持ちでない場合";

  @override
  String get registerText => "登録";

  @override
  String get resetPasswordButtonLabel => "パスワードを再設定";

  @override
  String get sendLinkButtonLabel => "マジックリンクで送信";

  @override
  String get signInActionText => "ログイン";

  @override
  String get signInHintText => "すでにアカウントをお持ちの場合";

  @override
  String get signInMethods => "ログイン方法";

  @override
  String get signInText => "ログイン";

  @override
  String get signInWithAppleButtonText => "Apple でサインイン";

  @override
  String get signInWithEmailLinkSentText =>
      "マジックリンクをメールでお送りしました。メールを確認し、リンクを使用してログインしてください";

  @override
  String get signInWithEmailLinkViewTitleText => "マジックリンクでログイン";

  @override
  String get signInWithFacebookButtonText => "Facebook でログイン";

  @override
  String get signInWithGoogleButtonText => "Google でログイン";

  @override
  String get signInWithPhoneButtonText => "携帯電話を使用してログイン";

  @override
  String get signInWithTwitterButtonText => "Twitter でログイン";

  @override
  String get signOutButtonText => "ログアウト";

  @override
  String get smsAutoresolutionFailedError =>
      "SMS コードを自動で解決できませんでした。コードを手動で入力してください";

  @override
  String get southInitialLabel => "S";

  @override
  String get stringLabel => "文字列";

  @override
  String get timestampLabel => "タイムスタンプ";

  @override
  String get typeLabel => "タイプ";

  @override
  String get unknownError => "不明なエラーが発生しました";

  @override
  String get updateLabel => "アップデート";

  @override
  String get userNotFoundErrorText => "アカウントが存在しません";

  @override
  String get valueLabel => "値";

  @override
  String get verifyCodeButtonText => "確認";

  @override
  String get verifyingSMSCodeText => "SMS コードを確認しています...";

  @override
  String get verifyItsYouText => "ご本人確認";

  @override
  String get verifyPhoneNumberButtonText => "次へ";

  @override
  String get westInitialLabel => "W";

  @override
  String get wrongOrNoPasswordErrorText => "パスワードが無効か、ユーザーにパスワードが設定されていません";

  @override
  String get uploadButtonText => "ファイルをアップロード";

  @override
  String get verifyEmailTitle => "メールを確認";

  @override
  String get verificationEmailSentText =>
      "あなたのメールアドレスに確認メールが送信されました。メールを確認し、リンクをクリックしてメールアドレスを確認してください。";

  @override
  String get verificationFailedText => "メールアドレスを確認できませんでした。";

  @override
  String get resendVerificationEmailButtonLabel => "確認メールを再送する";

  @override
  String get verificationEmailSentTextShort => "確認メールが送信されました";

  @override
  String get emailIsNotVerifiedText => "メールは確認されていません";

  @override
  String get waitingForEmailVerificationText => "メールの確認を待っています";

  @override
  String get dismissButtonLabel => "閉じる";

  @override
  String get okButtonLabel => "OK";

  @override
  String get checkEmailHintText => "メールを確認し、リンクをクリックしてメールアドレスを確認してください。";

  @override
  String get doneButtonLabel => "完了";

  @override
  String get invalidVerificationCodeErrorText => "入力したコードが無効です。もう一度お試しください。";

  @override
  String get ulinkProviderAlertTitle => "プロバイダーのリンク解除";

  @override
  String get confirmUnlinkButtonLabel => "リンク解除";

  @override
  String get cancelButtonLabel => "キャンセル";

  @override
  String get unlinkProviderAlertMessage => "プロバイダーのリンクを解除してもよろしいですか？";

  @override
  String get weakPasswordErrorText => "パスワードは少なくとも6文字である必要があります";

  @override
  String get confirmDeleteAccountAlertTitle => "アカウント削除の確認";

  @override
  String get confirmDeleteAccountAlertMessage => "アカウントを削除してもよろしいですか？";

  @override
  String get confirmDeleteAccountButtonLabel => "はい、削除します";
}

==> firebase_ui_localizations-1.11.0.tar.gz: lib/src/lang/ja.dart <==
// Copyright 2024, the Chromium project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
import '../default_localizations.dart';

class JaLocalizations extends FirebaseUILocalizationLabels {
  const JaLocalizations();

  @override
  String get accessDisabledErrorText => "このアカウントへのアクセスが一時的に無効になっています";

  @override
  String get arrayLabel => "配列";

  @override
  String get booleanLabel => "ブール値";

  @override
  String get cancelLabel => "キャンセル";

  @override
  String get chooseACountry => "国を選択";

  @override
  String get confirmPasswordDoesNotMatchErrorText => "パスワードが一致しません";

  @override
  String get confirmPasswordInputLabel => "パスワードを確認";

  @override
  String get confirmPasswordIsRequiredErrorText => "パスワードを確認してください";

  @override
  String get continueText => "続行";

  @override
  String get countryCode => "コード";

  @override
  String get credentialAlreadyInUseErrorText =>
      "このプロバイダは、すでに別のユーザーアカウントに関連付けられています。";

  @override
  String get deleteAccount => "アカウントを削除";

  @override
  String get differentMethodsSignInTitleText => "次のいずれかの方法を使用してサインインします";

  @override
  String get disable => "無効にする";

  @override
  String get eastInitialLabel => "E";

  @override
  String get emailInputLabel => "メール";

  @override
  String get emailIsRequiredErrorText => "メールアドレスは必須です";

  @override
  String get emailLinkSignInButtonLabel => "マジックリンクでサインイン";

  @override
  String get emailTakenErrorText => "このようなメールアドレスを持つアカウントはすでに存在します";

  @override
  String get enable => "有効にする";

  @override
  String get enableMoreSignInMethods => "その他のサインイン方法を有効にします";

  @override
  String get enterSMSCodeText => "SMSコードを入力";

  @override
  String get findProviderForEmailTitleText => "メールアドレスを入力して続行";

  @override
  String get forgotPasswordButtonLabel => "パスワードをお忘れの場合";

  @override
  String get forgotPasswordHintText =>
      "メールアドレスを入力してください。パスワードを再設定するためのリンクが送信されます";

  @override
  String get forgotPasswordViewTitle => "パスワードをお忘れの場合";

  @override
  String get geopointLabel => "地理位置情報";

  @override
  String get goBackButtonLabel => "戻る";

  @override
  String get invalidCountryCode => "コードが無効です";

  @override
  String get isNotAValidEmailErrorText => "有効なメールアドレスを入力してください";

  @override
  String get latitudeLabel => "緯度";

  @override
  String get linkEmailButtonText => "次へ";

  @override
  String get longitudeLabel => "経度";

  @override
  String get mapLabel => "地図";

  @override
  String get mfaTitle => "2段階認証プロセス";

  @override
  String get name => "名前";

  @override
  String get northInitialLabel => "N";

  @override
  String get nullLabel => "null";

  @override
  String get numberLabel => "番号";

  @override
  String get off => "オフ";

  @override
  String get on => "オン";

  @override
  String get passwordInputLabel => "パスワード";

  @override
  String get passwordIsRequiredErrorText => "パスワードは必須です";

  @override
  String get passwordResetEmailSentText =>
      "パスワードを再設定するためのリンクをメールでお送りしました。メールをご確認ください。";

  @override
  String get phoneInputLabel => "電話番号";

  @override
  String get phoneNumberInvalidErrorText => "電話番号が無効です";

  @override
  String get phoneNumberIsRequiredErrorText => "電話番号は必須です";

  @override
  String get phoneVerificationViewTitleText => "電話番号を入力してください";

  @override
  String get profile => "プロファイル";

  @override
  String get provideEmail => "メールアドレスとパスワードの入力";

  @override
  String get referenceLabel => "リファレンス";

  @override
  String get registerActionText => "登録";

  @override
  String get registerHintText => "アカウントをお持ちでない場合";

  @override
  String get registerText => "登録";

  @override
  String get resetPasswordButtonLabel => "パスワードを再設定";

  @override
  String get sendLinkButtonLabel => "マジックリンクで送信";

  @override
  String get signInActionText => "サインイン";

  @override
  String get signInHintText => "すでにアカウントをお持ちの場合";

  @override
  String get signInMethods => "サインイン方法";

  @override
  String get signInText => "サインイン";

  @override
  String get signInWithAppleButtonText => "Appleでサインイン";

  @override
  String get signInWithEmailLinkSentText =>
      "マジックリンクをメールでお送りしました。メールを確認し、リンクを使用してサインインしてください";

  @override
  String get signInWithEmailLinkViewTitleText => "マジックリンクでサインイン";

  @override
  String get signInWithFacebookButtonText => "Facebookでサインイン";

  @override
  String get signInWithGoogleButtonText => "Googleでサインイン";

  @override
  String get signInWithPhoneButtonText => "携帯電話を使用してサインイン";

  @override
  String get signInWithTwitterButtonText => "Twitterでサインイン";

  @override
  String get signOutButtonText => "ログアウト";

  @override
  String get smsAutoresolutionFailedError =>
      "SMS コードを自動で解決できませんでした。コードを手動で入力してください";

  @override
  String get southInitialLabel => "S";

  @override
  String get stringLabel => "文字列";

  @override
  String get timestampLabel => "タイムスタンプ";

  @override
  String get typeLabel => "タイプ";

  @override
  String get unknownError => "不明なエラーが発生しました";

  @override
  String get updateLabel => "アップデート";

  @override
  String get userNotFoundErrorText => "アカウントが存在しません";

  @override
  String get valueLabel => "値";

  @override
  String get verifyCodeButtonText => "確認";

  @override
  String get verifyingSMSCodeText => "SMSコードを確認しています...";

  @override
  String get verifyItsYouText => "ご本人確認";

  @override
  String get verifyPhoneNumberButtonText => "次へ";

  @override
  String get westInitialLabel => "W";

  @override
  String get wrongOrNoPasswordErrorText => "パスワードが無効か、ユーザーにパスワードが設定されていません";

  @override
  String get uploadButtonText => "ファイルをアップロード";

  @override
  String get verifyEmailTitle => "メールを確認";

  @override
  String get verificationEmailSentText =>
      "あなたのメールアドレスに確認メールが送信されました。メールを確認し、リンクをクリックしてメールアドレスを確認してください。";

  @override
  String get verificationFailedText => "メールアドレスを確認できませんでした。";

  @override
  String get resendVerificationEmailButtonLabel => "確認メールを再送する";

  @override
  String get verificationEmailSentTextShort => "確認メールが送信されました";

  @override
  String get emailIsNotVerifiedText => "メールは確認されていません";

  @override
  String get waitingForEmailVerificationText => "メールの確認を待っています";

  @override
  String get dismissButtonLabel => "閉じる";

  @override
  String get okButtonLabel => "OK";

  @override
  String get checkEmailHintText => "メールを確認し、リンクをクリックしてメールアドレスを確認してください。";

  @override
  String get doneButtonLabel => "完了";

  @override
  String get invalidVerificationCodeErrorText => "入力したコードが無効です。もう一度お試しください。";

  @override
  String get ulinkProviderAlertTitle => "プロバイダーのリンク解除";

  @override
  String get confirmUnlinkButtonLabel => "リンク解除";

  @override
  String get cancelButtonLabel => "キャンセル";

  @override
  String get unlinkProviderAlertMessage => "プロバイダーのリンクを解除してもよろしいですか？";

  @override
  String get weakPasswordErrorText => "パスワードは少なくとも6文字である必要があります";

  @override
  String get confirmDeleteAccountAlertTitle => "アカウント削除の確認";

  @override
  String get confirmDeleteAccountAlertMessage => "アカウントを削除してもよろしいですか？";

  @override
  String get confirmDeleteAccountButtonLabel => "はい、削除します";

  @override
  String get sendVerificationEmailLabel => "Send verification email";
}
